@@ -629,9 +629,9 @@ static bool ParseOperand(const char *line,unsigned int *lineIndex,OPERAND *opera
 	REGISTER
 		reg;
 
-	if(line[*lineIndex]=='@')
+	if(ParseIndirectOperand(line,lineIndex,operand))
 	{
-		return(ParseIndirectOperand(line,lineIndex,operand));
+		return(true);
 	}
 	else
 	{
