@@ -1478,7 +1478,6 @@ static bool HandleAVRDW(const char *opcodeName,const char *line,unsigned int *li
 
 	done=false;
 	fail=!ProcessLineLocationLabel(lineLabel);		// deal with any label on the line
-	StartByteGeneration();
 	while(!done&&!fail)
 	{
 		if(ParseQuotedString(line,lineIndex,'"','"',outputString,&stringLength))
@@ -1497,14 +1496,7 @@ static bool HandleAVRDW(const char *opcodeName,const char *line,unsigned int *li
 		else if(ParseExpression(line,lineIndex,&value,&unresolved))
 		{
 			CheckWordRange(value,true,true);
-			if(GenerateAVRByte(value>>8,listingRecord))
-			{
-				fail=!GenerateAVRByte(value&0xFF,listingRecord);
-			}
-			else
-			{
-				fail=true;
-			}
+			fail=!GenerateAVRWord(value,listingRecord);
 		}
 		else
 		{
